@@ -27,13 +27,6 @@ func (h *Handler) processImageStreamWatchEvent(is *imagev1.ImageStream, deleted
 	} else {
 		logrus.Debugf("Imagestream %s watch event do upsert %v; no errors in prep %v,  possibly update operator conditions %v", is.Name, doUpsert, err == nil, cfg != nil)
 	}
-	if cfg != nil {
-		if util.IsNonX86Arch(cfg) {
-			logrus.Printf("ignoring watch event for imagestream %s ignored because we are on %s",
-				is.Name, cfg.Spec.Architectures[0])
-			return nil
-		}
-	}
 	if !doUpsert {
 		if err != nil {
 			return err
@@ -273,6 +266,16 @@ func (h *Handler) upsertImageStream(imagestreamInOperatorImage, imagestreamInClu
 
 func (h *Handler) updateDockerPullSpec(oldies []string, imagestream *imagev1.ImageStream, opcfg *v1.Config) {
 	logrus.Debugf("updateDockerPullSpec stream %s has repo %s", imagestream.Name, imagestream.Spec.DockerImageRepository)
+	// we always want to leave the jenkins images as using the payload set to the IMAGE* env's;
+	switch imagestream.Name {
+	case "jenkins":
+		return
+	case "jenkins-agent-nodejs":
+		return
+	case "jenkins-agent-maven":
+		return
+	}
+
 	// don't mess with deprecated field unless it is actually set with something
 	if len(imagestream.Spec.DockerImageRepository) > 0 &&
 		!strings.HasPrefix(imagestream.Spec.DockerImageRepository, opcfg.Spec.SamplesRegistry) {
